# HG changeset patch
# Parent 47ed4f745a0744c052bf5fd674ddb22d5a09ae1b
use relative importing for path specified extension loading

To use hgsubversion loaded by specifying location without
installation, relative importing should be used to avoid
strange error "module not found".

Relative importing should be used to avoid error "module not found"
when hgsubversion is loaded with location like this:

[extnsions]
hgsubversion = /path/to/hgsubversion

Note that this changes does not use standard style of relative
import statement like "from .. import util" because python 2.4
does not support it and cause syntax error. So equivalent code
is used to get module via mercurial.extensions.find().

diff -r 47ed4f745a07 hgsubversion/layouts/detect.py
--- a/hgsubversion/layouts/detect.py	Fri Jul 12 11:21:41 2013 +0900
+++ b/hgsubversion/layouts/detect.py	Thu Aug 15 20:27:45 2013 +0900
@@ -10,7 +10,14 @@
 
 from mercurial import util as hgutil
 
-from hgsubversion import svnwrap
+# relative importing which also work with python 2.4
+# this is equivalent to: "from .. import svnwrap"
+from mercurial import extensions
+try:
+    svnwrap = extensions.find('hgsubversion').svnwrap
+except KeyError:
+    # ignore for loading from setup.py
+    pass
 
 def layout_from_subversion(svn, revision=None, ui=None):
     """ Guess what layout to use based on directories under the svn root.
diff -r 47ed4f745a07 hgsubversion/layouts/standard.py
--- a/hgsubversion/layouts/standard.py	Fri Jul 12 11:21:41 2013 +0900
+++ b/hgsubversion/layouts/standard.py	Thu Aug 15 20:27:45 2013 +0900
@@ -2,7 +2,15 @@
 import pickle
 
 import base
-import hgsubversion.util as util
+
+# relative importing which also work with python 2.4
+# this is equivalent to: "from .. import util"
+from mercurial import extensions
+try:
+    svnwrap = extensions.find('hgsubversion').svnwrap
+except KeyError:
+    # ignore for loading from setup.py
+    pass
 
 class StandardLayout(base.BaseLayout):
     """The standard trunk, branches, tags layout"""
